<?xml version="1.0" ?><!DOCTYPE TS><TS language="sq" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!message" line="0"/>
			<source>Authentication is required to read disk information</source>
			<translation>Për të lexuar të dhëna disku lypset mirëfilltësim</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!description" line="0"/>
			<source>Run Disk Manager Need Authentication</source>
			<translation>Xhirimi i Përgjegjësit të Disqeve Lyp Mirëfilltësim</translation>
		</message>
	</context>
</TS>